@@ -1,28 +1,17 @@
 package Mojolicious::Plugin::RenderCGI::CGI;
-use Mojo::Base -strict;
+use Mojo::Base 'CGI';
 #~ use Capture::Tiny qw(capture);
 
 sub new {
     my $proto = shift;
     my $class = ref $proto || $proto;
-    my $self = {};
-    bless ($self, $class);
-    $self->init(@_);
-    return $self;
-}
-
-sub init {
-  my $self = shift;
-  my %arg = @_;
-  push @{$arg{import}}, 'escapeHTML';
-  require CGI;
-  CGI->import(@{$arg{import}});
-  $self->{cgi} = CGI->new();
-  return $self;
+    $class->import(@_, 'escapeHTML', '-utf8');
+    my $cgi = $class->SUPER::new();
+    return $cgi;
 }
 
 
-sub compile {
+sub template {
   my $self = shift;
   my ($code) = @_;
 
@@ -31,6 +20,7 @@ sub {
 my (\$self, \$c,);
 \$self = \$c = shift;
 my \$cgi = shift;
+undef, # может комменты придут без кода
 $code
 }
 CODE
